import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface BitObject {
    value: string;
}
interface Bit<N extends number> {
    bit: string;
    value: string;
    postgres: string;
    get n(): N;
    toString(): string;
    toNumber(): number;
    toJSON(): BitObject;
    equals(string: string): boolean;
    equals(number: number): boolean;
    equals(object: Bit<N> | BitObject): boolean;
    safeEquals(string: string): SafeEquals<Bit<N>>;
    safeEquals(number: number): SafeEquals<Bit<N>>;
    safeEquals(object: Bit<N> | BitObject): SafeEquals<Bit<N>>;
}
interface BitConstructor<N extends number> {
    from(string: string): Bit<N>;
    from(number: number): Bit<N>;
    from(object: Bit<N> | BitObject): Bit<N>;
    safeFrom(string: string): SafeFrom<Bit<N>>;
    safeFrom(number: number): SafeFrom<Bit<N>>;
    safeFrom(object: Bit<N> | BitObject): SafeFrom<Bit<N>>;
    /**
     * Returns `true` if `object` is a `Bit`, `false` otherwise.
     */
    isBit(object: any): object is Bit<N>;
    /**
     * Returns `true` if `object` is a `Bit<N>`, `false` otherwise.
     */
    isBit<NN extends number = N>(object: any, n: NN): object is Bit<NN>;
    /**
     * Returns `true` if `object` is a `Bit<N>`, `false` otherwise.
     */
    isAnyBit(object: any): object is Bit<number>;
    /**
     * Get a `Bit` constructor for a specific `n`.
     * @param n The number of bits.
     */
    setN<N extends number = 1>(n: N): BitConstructor<N>;
    /**
     * Get the `n` value for this `Bit` constructor.
     * @returns The `n` value.
     */
    get n(): N;
}
declare const Bit: BitConstructor<1>;
export { Bit, BitConstructor, BitObject };
