import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface CharacterVaryingObject {
    value: string;
}
interface CharacterVarying<N extends number> {
    characterVarying: string;
    value: string;
    postgres: string;
    get n(): N;
    toString(): string;
    toJSON(): CharacterVaryingObject;
    equals(string: string): boolean;
    equals(object: CharacterVarying<N> | CharacterVaryingObject): boolean;
    safeEquals(string: string): SafeEquals<CharacterVarying<N>>;
    safeEquals(object: CharacterVarying<N> | CharacterVaryingObject): SafeEquals<CharacterVarying<N>>;
}
interface CharacterVaryingConstructor<N extends number> {
    from(string: string): CharacterVarying<N>;
    from(object: CharacterVarying<N> | CharacterVaryingObject): CharacterVarying<N>;
    safeFrom(string: string): SafeFrom<CharacterVarying<N>>;
    safeFrom(object: CharacterVarying<N> | CharacterVaryingObject): SafeFrom<CharacterVarying<N>>;
    /**
     * Returns `true` if `object` is a `CharacterVarying`, `false` otherwise.
     */
    isCharacterVarying(object: any): object is CharacterVarying<N>;
    /**
     * Returns `true` if `object` is a `CharacterVarying<N>`, `false` otherwise.
     */
    isCharacterVarying<N extends number = number>(object: any, n: N): object is CharacterVarying<N>;
    /**
     * Returns `true` if `object` is a `CharacterVarying<N>`, `false` otherwise.
     */
    isAnyCharacterVarying(object: any): object is CharacterVarying<number>;
    /**
     * Get a `CharacterVarying` constructor for a specific `n`.
     * @param n The number of characters.
     */
    setN<N extends number = number>(n: N): CharacterVaryingConstructor<N>;
    /**
     * Get the `n` value for this `CharacterVarying` constructor.
     * @returns The `n` value.
     */
    get n(): N;
}
declare const CharacterVarying: CharacterVaryingConstructor<number>;
export { CharacterVarying, CharacterVaryingConstructor, CharacterVaryingObject };
