import { DateTime, Zone } from "luxon";
import { Offset } from "../../types/Offset.js";
import { OffsetDirection, OffsetDirectionType } from "../../types/OffsetDirection.js";
import { SafeEquals } from "../../types/SafeEquals.js";
import { SafeFrom } from "../../types/SafeFrom.js";
import { Time } from "./Time.js";
interface TimeTZObject {
    hour: number;
    minute: number;
    second: number;
    offset: Offset;
}
interface TimeTZ {
    hour: number;
    minute: number;
    second: number;
    offset: Offset;
    value: number;
    postgres: string;
    toString(): string;
    toNumber(): number;
    toJSON(): TimeTZObject;
    toTime(): Time;
    /**
     * @param zone The zone to convert the time to. Defaults to 'local'.
     */
    toDateTime(zone?: string | Zone | undefined): DateTime;
    /**
     * @param zone The zone to convert the time to. Defaults to 'local'.
     */
    toJSDate(zone?: string | Zone | undefined): globalThis.Date;
    equals(string: string): boolean;
    equals(unixTimestamp: number): boolean;
    equals(hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): boolean;
    equals(timetz: TimeTZ | globalThis.Date | DateTime): boolean;
    equals(object: TimeTZObject): boolean;
    safeEquals(string: string): SafeEquals<TimeTZ>;
    safeEquals(unixTimestamp: number): SafeEquals<TimeTZ>;
    safeEquals(hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): SafeEquals<TimeTZ>;
    safeEquals(timetz: TimeTZ | globalThis.Date | DateTime): SafeEquals<TimeTZ>;
    safeEquals(object: TimeTZObject): SafeEquals<TimeTZ>;
}
interface TimeTZConstructor {
    from(string: string): TimeTZ;
    from(unixTimestamp: number): TimeTZ;
    from(hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): TimeTZ;
    from(timetz: TimeTZ | globalThis.Date | DateTime): TimeTZ;
    from(object: TimeTZObject): TimeTZ;
    safeFrom(string: string): SafeFrom<TimeTZ>;
    safeFrom(unixTimestamp: number): SafeFrom<TimeTZ>;
    safeFrom(hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): SafeFrom<TimeTZ>;
    safeFrom(timetz: TimeTZ | globalThis.Date | DateTime): SafeFrom<TimeTZ>;
    safeFrom(object: TimeTZObject): SafeFrom<TimeTZ>;
    /**
     * Returns `true` if `object` is a `TimeTZ`, `false` otherwise.
     */
    isTimeTZ(object: any): object is TimeTZ;
}
declare const TimeTZ: TimeTZConstructor;
export { TimeTZ, TimeTZConstructor, TimeTZObject };
