import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Point, PointObject } from "./Point.js";
interface PolygonObject {
    points: Point[];
}
interface RawPolygonObject {
    points: PointObject[];
}
interface Polygon {
    points: Point[];
    value: string;
    postgres: string;
    toString(): string;
    toJSON(): RawPolygonObject;
    equals(string: string): boolean;
    equals(points: Point[]): boolean;
    equals(point: Point, ...points: Point[]): boolean;
    equals(polygon: Polygon): boolean;
    equals(object: PolygonObject | RawPolygonObject): boolean;
    safeEquals(string: string): SafeEquals<Polygon>;
    safeEquals(points: Point[]): SafeEquals<Polygon>;
    safeEquals(point: Point, ...points: Point[]): SafeEquals<Polygon>;
    safeEquals(polygon: Polygon): SafeEquals<Polygon>;
    safeEquals(object: PolygonObject | RawPolygonObject): SafeEquals<Polygon>;
}
interface PolygonConstructor {
    from(string: string): Polygon;
    from(points: Point[]): Polygon;
    from(point: Point, ...points: Point[]): Polygon;
    from(polygon: Polygon): Polygon;
    from(object: PolygonObject | RawPolygonObject): Polygon;
    safeFrom(string: string): SafeFrom<Polygon>;
    safeFrom(points: Point[]): SafeFrom<Polygon>;
    safeFrom(point: Point, ...points: Point[]): SafeFrom<Polygon>;
    safeFrom(polygon: Polygon): SafeFrom<Polygon>;
    safeFrom(object: PolygonObject | RawPolygonObject): SafeFrom<Polygon>;
    /**
     * Returns `true` if `object` is a `Polygon`, `false` otherwise.
     */
    isPolygon(object: any): object is Polygon;
}
declare const Polygon: PolygonConstructor;
export { Polygon, PolygonConstructor, PolygonObject, RawPolygonObject };
