import type { BigNumber } from "bignumber.js";
import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface MoneyObject {
    value: string;
}
interface Money {
    money: BigNumber;
    value: string;
    postgres: string;
    toString(): string;
    toBigNumber(): BigNumber;
    toJSON(): MoneyObject;
    equals(string: string): boolean;
    equals(number: number): boolean;
    equals(bigInt: bigint): boolean;
    equals(bigNumber: BigNumber): boolean;
    equals(object: Money | MoneyObject): boolean;
    safeEquals(string: string): SafeEquals<Money>;
    safeEquals(number: number): SafeEquals<Money>;
    safeEquals(bigInt: bigint): SafeEquals<Money>;
    safeEquals(bigNumber: BigNumber): SafeEquals<Money>;
    safeEquals(object: Money | MoneyObject): SafeEquals<Money>;
}
interface MoneyConstructor {
    from(string: string): Money;
    from(number: number): Money;
    from(bigInt: bigint): Money;
    from(bigNumber: BigNumber): Money;
    from(object: Money | MoneyObject): Money;
    safeFrom(string: string): SafeFrom<Money>;
    safeFrom(number: number): SafeFrom<Money>;
    safeFrom(bigInt: bigint): SafeFrom<Money>;
    safeFrom(bigNumber: BigNumber): SafeFrom<Money>;
    safeFrom(object: Money | MoneyObject): SafeFrom<Money>;
    /**
     * Returns `true` if `object` is a `Money`, `false` otherwise.
     */
    isMoney(object: any): object is Money;
}
declare const Money: MoneyConstructor;
export { Money, MoneyConstructor, MoneyObject };
