/* eslint-disable unicorn/filename-case */
import { Address4, Address6 } from "ip-address";
import { IPVersion } from "../../types/IpType.js";
const IPAddress = {
    from(argument) {
        if (typeof argument === "string") {
            return new IPAddressClass({
                IPAddress: argument,
            });
        }
        else if (IPAddress.isIPAddresss(argument))
            return new IPAddressClass(argument.toJSON());
        else
            return new IPAddressClass(argument);
    },
    isIPAddresss(object) {
        return object instanceof IPAddressClass;
    },
};
class IPAddressClass {
    constructor(data) {
        try {
            this._IPAddress = new Address4(data.IPAddress);
            return;
        }
        catch { }
        try {
            this._IPAddress = new Address6(data.IPAddress);
            return;
        }
        catch { }
        throw new Error("Invalid IP Address string");
    }
    toString() {
        return this._IPAddress.address;
    }
    toJSON() {
        return {
            IPAddress: this._IPAddress.address,
        };
    }
    equals(otherIPAddress) {
        return typeof otherIPAddress === "string"
            ? otherIPAddress.toLowerCase() === this._IPAddress.address.toLowerCase()
            : otherIPAddress.IPAddress.toLowerCase() === this._IPAddress.address.toLowerCase();
    }
    get IPAddress() {
        return this._IPAddress.address;
    }
    set IPAddress(IPAddress) {
        try {
            this._IPAddress = new Address4(IPAddress);
            return;
        }
        catch { }
        try {
            this._IPAddress = new Address6(IPAddress);
            return;
        }
        catch { }
        throw new Error("Invalid IP Address");
    }
    get IPAddressMinusSuffix() {
        return this._IPAddress.addressMinusSuffix ?? this._IPAddress.address;
    }
    get version() {
        return this._IPAddress.v4 ? IPVersion.IPv4 : IPVersion.IPv6;
    }
    get subnet() {
        return this._IPAddress.subnet;
    }
    get subnetMask() {
        return this._IPAddress.subnetMask;
    }
    get startAddress() {
        return IPAddress.from(this._IPAddress.startAddress().address);
    }
    get endAddress() {
        return IPAddress.from(this._IPAddress.endAddress().address);
    }
    contains(otherIPAddress) {
        let address;
        if (typeof otherIPAddress === "string") {
            try {
                address = new Address4(otherIPAddress);
            }
            catch { }
            try {
                address ??= new Address6(otherIPAddress);
            }
            catch {
                return false;
            }
        }
        else {
            try {
                address = new Address4(otherIPAddress.IPAddress);
            }
            catch { }
            try {
                address ??= new Address6(otherIPAddress.IPAddress);
            }
            catch {
                return false;
            }
        }
        return address.isInSubnet(this._IPAddress);
    }
    toIPAddress4() {
        return this._IPAddress.v4 ? this._IPAddress : null;
    }
    toIPAddress6() {
        return this._IPAddress.v4 ? null : this._IPAddress;
    }
}
export { IPAddress };
//# sourceMappingURL=IPAddress.js.map