/// <reference types="node" resolution-mode="require"/>
import { RandomUUIDOptions } from "node:crypto";
import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
interface UUIDObject {
    value: string;
}
interface UUID {
    uuid: string;
    value: string;
    postgres: string;
    toString(): string;
    toJSON(): UUIDObject;
    equals(string: string): boolean;
    equals(object: UUID | UUIDObject): boolean;
    safeEquals(string: string): SafeEquals<UUID>;
    safeEquals(object: UUID | UUIDObject): SafeEquals<UUID>;
}
interface UUIDConstructor {
    from(string: string): UUID;
    from(object: UUID | UUIDObject): UUID;
    safeFrom(string: string): SafeFrom<UUID>;
    safeFrom(object: UUID | UUIDObject): SafeFrom<UUID>;
    /**
     * Generates a random [RFC 4122](https://www.rfc-editor.org/rfc/rfc4122.txt) version 4 UUID. The UUID is generated using a
     * cryptographic pseudorandom number generator.
     */
    generate(options?: RandomUUIDOptions): UUID;
    /**
     * Returns `true` if `object` is a `UUID`, `false` otherwise.
     */
    isUUID(object: any): object is UUID;
}
declare const UUID: UUIDConstructor;
export { UUID, UUIDConstructor, UUIDObject };
