/* eslint-disable unicorn/filename-case */
import { isValid } from "@postgresql-typed/util";
import { getErrorMap } from "./errorMap.js";
import { PGTPError } from "./PGTPError.js";
export class PGTPConstructorBase {
    constructor() {
        this.from = this.from.bind(this);
        this.safeFrom = this.safeFrom.bind(this);
    }
    from(...data) {
        const result = this.safeFrom(...data);
        if (result.success)
            return result.data;
        throw result.error;
    }
    safeFrom(...data) {
        const context = {
            issue: null,
            errorMap: getErrorMap(),
            data,
        }, result = this._parse(context);
        return this._handleResult(context, result);
    }
    _handleResult(context, result) {
        if (isValid(result))
            return { success: true, data: result.value };
        if (!context.issue)
            throw new Error("Validation failed but no issue detected.");
        const error = new PGTPError(context.issue);
        return { success: false, error };
    }
    setIssueForContext(context, issueData) {
        context.issue = {
            ...issueData,
            message: context.errorMap(issueData).message,
        };
    }
}
//# sourceMappingURL=PGTPConstructorBase.js.map